#
# spec file for package oc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           oc
Version:        4.18.0
Release:        1.1
Summary:        Openshift / OKD Client CLI
License:        Apache-2.0
URL:            https://github.com/openshift/oc
Source:         oc-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22.5
BuildRequires:  krb5-devel
BuildRequires:  libgpgme-devel
BuildRequires:  zsh

# this package contains a kubectl link, so we need a Conflicts
Conflicts:      kubernetes-client
Conflicts:      kuberlr
Conflicts:      kubernetes-client-provider

%description
With OpenShift Client CLI (oc), you can create applications and manage
OpenShift resources. It is built on top of kubectl which means it provides its
full capabilities to connect with any kubernetes compliant cluster, and on top
adds commands simplifying interaction with an OpenShift cluster.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch
Conflicts:      kubernetes-client-bash-completion

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch
Conflicts:      kubernetes-client-fish-completion

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch
Conflicts:      kubernetes-client-zsh-completion

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
# hash will be shortened by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

OC_KUBE_GIT_VERSION="$(awk -F '"' '/^KUBE_GIT_VERSION/ {print $2}' Makefile)"
OC_KUBE_GIT_MAJOR_VERSION="$(awk -F '.' '/^KUBE_GIT_VERSION/ {gsub(/^.*v/, "", $1); print $1}' Makefile)"
OC_KUBE_GIT_MINOR_VERSION="$(awk -F '.' '/^KUBE_GIT_VERSION/ {print $2}' Makefile)"
OC_GO_TAGS="$(awk -F "'" '/^GO_BUILD_FLAGS :=/ {print $2}' Makefile)"

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X k8s.io/component-base/version.gitMajor=${OC_KUBE_GIT_MAJOR_VERSION} \
   -X k8s.io/component-base/version.gitMinor=${OC_KUBE_GIT_MINOR_VERSION} \
   -X k8s.io/component-base/version.gitVersion=${OC_KUBE_GIT_VERSION} \
   -X k8s.io/component-base/version.gitCommit=${COMMIT_HASH:0:8} \
   -X k8s.io/component-base/version.buildDate=${BUILD_DATE} \
   -X k8s.io/component-base/version.gitTreeState=clean \
   -X github.com/openshift/oc/pkg/version.versionFromGit=v%{version} \
   -X github.com/openshift/oc/pkg/version.commitFromGit=${COMMIT_HASH:0:8} \
   -X github.com/openshift/oc/pkg/version.gitTreeState=clean \
   -X github.com/openshift/oc/pkg/version.buildDate=${BUILD_DATE}" \
   -tags="${OC_GO_TAGS}" \
   -o bin/ ./cmd/oc ./tools/genman

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# Install man1 man pages
install -d -m 0755 %{buildroot}%{_mandir}/man1
./bin/genman %{buildroot}%{_mandir}/man1 oc

# create the kubectl link
cd %{buildroot}/%{_bindir}/
ln -s ./oc ./kubectl

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}
%{buildroot}/%{_bindir}/kubectl completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/kubectl

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish
%{buildroot}/%{_bindir}/kubectl completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/kubectl.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}
%{buildroot}/%{_bindir}/kubectl completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_kubectl

%check

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/kubectl
%{_mandir}/man1/oc*

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}
%{_datarootdir}/bash-completion/completions/kubectl

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish
%{_datarootdir}/fish/vendor_completions.d/kubectl.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}
%{_datarootdir}/zsh/site-functions/_kubectl

%changelog
* Tue Feb 25 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- remove leading v from version
- refactor spec to not hardcode kubernetes versions etc.
* Tue Feb 25 2025 opensuse_buildservice@ojkastl.de
- Update to version v4.18.0:
  * Address `github.com/docker/docker` CVE
  * OCPBUGS-38975: monitor should not exit for temp api disconnect
  * fix oc adm node-image create --pxe command to copy the correct
    artifacts
  * OCPBUGS-45991: Mark --report and --pxe flags as experimental
  * adm node-logs: Also parse logs when encountered with standard
    html header
  * Revert "OCPBUGS-37344: Skip inspection of the daemonset pods
    running on data plane"
  * OTA-1393: status: recognize the process of migration to
    multi-arch
  * make create and monitor logs more similar and uniform
  * NO-JIRA: adm release: cleanups (#1914)
  * pkg/cli/admin/upgrade/recommend: Fix "no updates to
    <MAJOR>.<MINOR> available" error message
  * pkg/cli/admin/upgrade/recommend: Expand "URL" to "Release URL"
  * pkg/cli/admin/upgrade/recommend: "no known issues..."
    placeholder
  * upgrade status: show updating cluster operator names in the
    output
  * added report flag to force saving the report
  * save automatically the report in case of failure
  * added progress on create command using the workflow report
  * manage error code from workflow report
  * refactor for checking explicitly min supported version
  * OTA-1224: status: simplify worker status line
  * Fix newapp unit test failure by using different image
  * pkg/cli/admin/upgrade/recommend: Treat Upgradeable=False as a
    conditional update risk
  * always retry in case of image pull error
  * pkg/cli/admin/upgrade: Propagate --force for --to-multi-arch
  * pkg/cli/admin/upgrade: Error on --to-multi-arch with
  - -to-latest
  * add MCO owners file
  * ensure mcs secret type before rotation
  * Add test to check RsyncInclude for PXE and ISO
  * OCPBUGS-43513: Show node-joiner container logs when error
    occurs
  * pkg/cli/admin/upgrade/recommend: Add --version option for
    specific releases
  * gather discovery when using inspect
  * Do not allow new line in user in create user
  * WRKLDS-1320: Support PXE files with "node-image create"
  * Remove redundant defaulting message in description
  * day2: additional rbac policy rules
  * NO-JIRA: Use suggested functions instead of deprecated ones
    (#1894)
  * pkg/cli/admin/upgrade/recommend: Show most-recent update
    options
  * Change kube version in image components
  * React to changes in kubectl/cmd.go
  * React to interface changes in commands
  * Bump k8s dependencies to 1.31.1 and go mod tidy/vendor
  * Update to new go version 1.22.5
  * OWNERS_ALIASES: Update username of David Hurta
  * pkg/cli/admin/upgrade/recommend/examples: Update examples
  * nodeimage create: fix outputname flag
  * Skip inspection of the daemonset pods running on data plane
  * pkg/cli/admin/upgrade/recommend: Add end-to-end output test
    coverage
  * Update root-approvers of oc
  * Check cast result in adm prune deployments to prevent panic
  * Rename rsync'd ISO file to -output-name value
  * Fixing -o flag in command example
  * Add HOST env var in oc debug for sos report collects more
  * OCPBUGS-38450: Fix copy artifacts for all CPU architectures
  * Fixing line that should be commented out
  * Updating ose-cli-artifacts-container image to be consistent
    with ART for 4.18 Reconciling with
    https://github.com/openshift/ocp-build-data/tree/827ab4ccce9cbbcf82c9dbaf6398b61d6cff8d7a/images/ose-cli-artifacts.yml
  * Updating openshift-enterprise-deployer-container image to be
    consistent with ART for 4.18 Reconciling with
    https://github.com/openshift/ocp-build-data/tree/827ab4ccce9cbbcf82c9dbaf6398b61d6cff8d7a/images/openshift-enterprise-deployer.yml
  * Updating ose-tools-container image to be consistent with ART
    for 4.18 Reconciling with
    https://github.com/openshift/ocp-build-data/tree/827ab4ccce9cbbcf82c9dbaf6398b61d6cff8d7a/images/ose-tools.yml
  * pkg/cli/admin/upgrade/: Add `oc adm upgrade recommend`
    subcommand
  * Updating openshift-enterprise-cli-container image to be
    consistent with ART for 4.18 Reconciling with
    https://github.com/openshift/ocp-build-data/tree/827ab4ccce9cbbcf82c9dbaf6398b61d6cff8d7a/images/openshift-enterprise-cli.yml
  * Update push targets of digest with new appended tags
  * OTA-1292: upgrade-status: improve messages for
    NotReady/DiskPressure/NetworkUnavailable
  * pkg/cli/admin/upgrade: --to-latest help "next" -> "latest"
  * OTA-1153: update-status: re-title "Operator Health"
  * OTA-1309: hide the empty "Worker Upgrade" section
  * node-joiner: use proxy settings when required
  * OTA-1292: upgrade-status: handle the OS image annotation better
  * make the idle command's scale update unconditional
  * OTA-1292: upgrade-status: handle unschedulable nodes better
  * upgrade-status: handle expected MCD state better
  * OTA-1212: Hide or condense control plane sections once
    successfully updated
  * `upgrade status`: improve tests for missing annotations
  * Adding examples for add-cluster-role-to-* and
    remove-cluster-role-from-* so they show in the CLI docs
  * upgrade-status: bubble up the reason for unavailable nodes
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.17.0:
  * node-joiner: use proxy settings when required
  * make the idle command's scale update unconditional
  * Adding examples for add-cluster-role-to-* and
    remove-cluster-role-from-* so they show in the CLI docs
  * Make MacAddress mandatory until installer validations are
    updated
  * Make MacAddress flag optional, add test for
    createConfigFileFromFlags
  * upgrade-status: add test coverage for a compact cluster and a
    single-node cluster
  * WRKLDS-1429: Adds a guardrail for node-image commands which is
    supported only for Openshift version 4.17 and later
  * upgrade-status: fix HasOSImage function
  * [OTA-1153]upgrade-status: communicate control plane completion
    clearly
  * WRKLDS-1316: Retry and do not fail when logs cannot be updated
  * added flags to support simper single node interface
  * WRKLDS-1316: Remove clusterversions from certificates api group
  * node-joiner: add the required role to support platform type
    validation
  * Separate api group for secrets
  * upgrade-status: fix a typo in README
  * Update command description
  * upgrade status: removes custom nodes from the worker pool (2)
  * Revert "upgrade status: removes custom nodes from the worker
    pool"
  * Remove common.go and incorporate review feedback
  * Create monitor run test and reuse common code
  * Revert "OCPBUGS-35994: pkg/cli/admin/upgrade/rollback: Drop
    this command"
  * upgarde status: use a table to represent node pools (#1821)
  * Minor wording tweaks for CLI help
  * Shared code placed in common.go
  * WRKLDS-1316: oc adm node-image monitor command
  * renamed to node-image
  * add-nodes: define empty commands structure
  * WRKLDS-1314: create image command (#1819)
  * upgrade status: removes custom nodes from the worker pool
  * Extend the kube version check for images/tools/Dockerfile
  * Remove invalid test cases: empty dockerfiles are no longer
    allowed
  * Lower case command value before comparision
  * bump(k8s.io)=1.30.2
  * pkg/cli/admin/mustgather: GA since and since-time flags
  * pkg/cli/admin/prune/renderedmachineconfigs: 'Error dry-run
    deleting'
  * pkg/cli/admin/upgrade/rollback: Drop this command
  * Inject ReleaseArch into openshift-install
  * `upgrade status`: revert to overestimating remaining time
  * `upgrade status`: lower estimated node actions to avoid
    inconsistency with estimation
  * `upgrade status`: overestimate total duration, not remaining
    time
  * `upgrade status`: change how last observed progress is computed
  * `upgrade status`: get baseline from history when possible
  * `upgrade status`: stalled or progressing-slow when over
    estimate
  * `upgrade status`: show <10m when estimate is lower than 10m
  * `upgrade status`: overestimate remaining time by 20%%
  * `update status`: Avoid projecting from small values
  * `upgrade status`: do not show estimate TTC when completed
  * `upgrade status`: estimate better via last observed progress
  * `update status`: use timewise completion estimate
  * `update status`: project estimate duration from elapsed
  * `update status`: add baseline control plane estimate duration
  * `update status`: truncate subsecond durations
  * `update status`: inject ns skew to eliminate input data
    rounding
  * Ignore pruning when deployment points to replicationcontroller
  * Update comment about using OpenFileSequential
  * `upgrade status`: polish alert insights
  * pkg/cli/admin/mustgather: don't manually delete cluster role
    binding
  * pkg/helpers: remove legacy pkg
  * pkg/cli/expose: override print flags for cmd
  * pkg/cli/create,pkg/cli/expose: use custom scheme
  * pkg/helpers/scheme: stop loading legacy schemes on global
    scheme
  * pkg/cli/admin/mustgather: gofumpt file
  * go 1.22 lint fix
  * Run make update
  * Update tools images kube version to 1.30.1
  * Manually bump indirect dependency runc to v1.1.12 to pull some
    fixes
  * Bump aws-sdk-go version to v1.53.12
  * React to type changes in containers/image/v5 v5.30.1 version
  * Bump containers/image/v5 to v5.30.1
  * Go 1.22 changes the escape output of some special characters
  * Bump go based imports
  * Bump k8s dependencies to 1.30
  * Remove already deprecated versions
  * Bump go version to 1.22
  * inspectalerts: refactor `getWithBearer` to try all urls in
    route
  * inspectalerts: use client-go wrappers for thanos call debugging
  * OCPBUGS-33896: `status/inspect-alerts`: handle non-200 by
    Thanos
  * Updating openshift-enterprise-deployer-container image to be
    consistent with ART for 4.17 Reconciling with
    https://github.com/openshift/ocp-build-data/tree/4c1326094222f9209876f06833179a1b9178faf7/images/openshift-enterprise-deployer.yml
  * `upgrade status`: upgrade -> update
  * OCPBUGS-33903: Simplify output when not updating
  * Updating ose-tools-container image to be consistent with ART
    for 4.17 Reconciling with
    https://github.com/openshift/ocp-build-data/tree/0a1310d4df1f00e3e218da6e356585997c7c0178/images/ose-tools.yml
  * Updating openshift-enterprise-cli-container image to be
    consistent with ART for 4.17 Reconciling with
    https://github.com/openshift/ocp-build-data/tree/0a1310d4df1f00e3e218da6e356585997c7c0178/images/openshift-enterprise-cli.yml
  * OCPBUGS-33762: Hardcode resource groups/kinds for now
  * update status: minor code cleanups
  * OCPBUGS-33898: `adm update status`: Show information about the
    upgrade target version (#1767)
  * add mock tests for alerts in oc adm upgrade status
  * Add s390x based oc into extraction target
  * pkg/cli/admin/upgrade/rollback: Gate on
    OC_ENABLE_CMD_UPGRADE_ROLLBACK
  * debug: set required-scc annotation to privileged for node debug
    pods
  * add alerts to update health in oc adm upgrade status
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 4.16.0:
  * OCPBUGS-33762: Hardcode resource groups/kinds for now
  * update status: minor code cleanups
  * `upgrade status`: polish alert insights
  * inspectalerts: refactor `getWithBearer` to try all urls in
    route
  * inspectalerts: use client-go wrappers for thanos call debugging
  * OCPBUGS-33896: `status/inspect-alerts`: handle non-200 by
    Thanos
  * add mock tests for alerts in oc adm upgrade status
  * add alerts to update health in oc adm upgrade status
  * `upgrade status`: upgrade -> update
  * OCPBUGS-33903: Simplify output when not updating
  * pkg/cli/admin/upgrade/rollback: Gate on
    OC_ENABLE_CMD_UPGRADE_ROLLBACK
  * adm update status: Fix target version field for install.
  * adm update status: Show information about upgrade target
    version
  * Add s390x based oc into extraction target
  * OCPBUGS-32682: Fix the retrieval of API objects with an empty
    name (#1765)
  * Support multiple icsps in migrate icsp
  * [OCPNODE-2282]Support multiple ImageDigestMirrorSet objects in
    the the single file
  * Switch cli-artifacts default oc to RHEL9
  * OTA-1275: cli/admin/release/git: use optimized git flags
  * Switch cli image to RHEL9 base image
  * pkg/cli/admin/upgrade/status: Drop free-form Progressing output
    line
  * pkg/cli/admin/upgrade/status: Move Failing from free-form to
    updateInsight
  * OTA-1174: `update status`: unify on `--details`
  * Bump go-jose indirect reference to 2.6.3
  * Improve error message when binary is not in target list
  * `upgrade status`: hint at using `--details=health`
  * `upgrade status`: ellipsize (duplicate) long names in messages
  * `upgrade status --detailed=health`: show involved resources
  * `update status`: Simplify CO status line
  * oc image extract: Print an error msg instead of panicking when
    all images are filtered out from the manifest list.
  * oc adm must-gather: print timestamp when logging
  * Changing the conditional risk to known issues
  * release: extract ccoctl.rhel8 and ccoctl.rhel9
  * `upgrade status`: always tabulate 'All is well'
  * `upgrade status`: ignore incomplete insights
  * `upgrade status`: pad linebreaks in descriptions
  * `upgrade status`: populate descriptions and refs for insights
  * `upgrade status`: `--details=health` shows reference and
    description
  * `upgrade status`: test `--detailed=all` in examples integration
    test
  * `upgrade status`: add `--detailed=nodes` that shows all nodes
  * add prune renderedmachineconfigs
  * indicate how many tests each feature has
  * update library-go for new api
  * update API for test reporting types
  * adm update status: Refactor node status
  * adm update status: Add status of control plane nodes
  * WRKLDS-1171: Add openshift-install-fips target to oc release
    extract
  * OCPBUGS-20097: Migrate tools image to RHEL9
  * Add help text the behavior of filter-by-os against single image
  * Add OIDC specific certificate authority bundle flag
  * update library-go
  * adjust rendering
  * update vendor for featuregate diffing
  * update featureset changes to table based view
  * Revert "WRKLDS-1128: cli/admin/release/git: use optimized git
    flags"
  * Remove some of newapp unit tests relying on external deprecated
    images
  * pkg/cli/admin/release/info: add back disk space note
  * Bump coreos/go-oidc to 3.10.0
  * pkg/cli/admin/release: fix git extract
  * pkg/cli/admin/release/git: fetch with blob:none
  * cli/admin/release/git: use optimized git flags
  * tools: extend the image with sosreport
  * vendor: Add machineconfiguration client and API
  * adm update status: Add MCO logic needed for worker node status
  * adm update status: Fix "Omitted additional... nodes" text
  * adm update status: Fix update duration after control plane is
    updated
  * adm update status: Add worker pool status
  * pkg/cli/admin/upgrade/status/examples: Add examples for worker
    pool status
  * Add images mismatching kubectl version into warning to track
  * pkg/cli/admin/upgrade/status/examples: Update examples
  * Drop issuer-url extraction instead rely on issuer-url flag
  * Introduce --issuer-url flag in oc login
  * Introduce certificate-authority flag for image related commands
  * oc idle: Remove redundant endpoint resource modification
  * Extract oc also for linux/ppc64le
  * Update some commands incorrect examples
  * oc adm catalog mirror: reconstruct the original digest with ':'
    for sha256 and sha512 algorithms on Windows
  * Print log rather than returning an error when kubectl version
    mistmaches
  * Revert "Revert "NO-JIRA: Bump k8s dependencies to 1.29.1""
  * Tools image no longer has python;adding
  * Revert "NO-JIRA: Bump k8s dependencies to 1.29.1"
  * oc adm catalog mirror: use ToSlash and FromSlash to unify the
    path separators
  * pkg/cli/admin/inspectalerts/OWNERS: Assign to monitoring team
  * pkg/cli/admin/inspectalerts: Pivot to Thanos /api/v1/alerts
  * pkg/cli/admin/inspectalerts: New tech-preview inspect-alerts
    subcommand
  * Bump k8s dependencies to 1.29.1
  * Revert "Fix --parallelism flag formatting in help"
  * Copy oc.rhel8 instead of symlink
  * Bump joelanford/ignore to bump go-git to 5.11.0
  * add FallbackToLogsOnError for easier debugging
  * pkg/cli/admin/inspect: use since/since-time for previous
    container logs
  * Fix --parallelism flag formatting in help
  * pkg/cli/admin/inspect: format RFC3339 parse error
  * Simplified kubectl component version check
  * Revert "Revert "WRKLDS-1016: Bump kube dependencies to 1.29.0""
  * Revert "WRKLDS-1016: Bump kube dependencies to 1.29.0"
  * Use correct hash sum of extracted tarball after re-signing with
    codesign
  * Add missing resources for describer test
  * React to argument order change in library-go func
  * Bump openshift dependencies to align with 1.29.0
  * React to plugin resolution to beta promotion
  * Wire warning printer to configflags for shortname warnings
  * Change type to VolumeResourceRequirements
  * Bump to 1.29.0
  * Wire oc login external OIDC issuer to oc get-token cred exec
    plugin
  * Add coreos/go-oidc and int128/oauth2cli and bump oauth2
    dependencies
  * Add get-token command as cred exec plugin
  * Unit tests for must-gather all-images
  * Add --all-images flag to must-gather
  * Consider kubectl version checks only in cli and cli-artifact
    images
  * Write oc adm must-gather logs into a file
  * oc adm must-gather: pull gather container logs
  * pkg/cli/admin/mustgather: add since and since-time flags to
    limit logs
  * adm update status: add TODOs to remind us to revise early
    decisions
  * pkg/cli/admin/inspect: use since/since-time for rotated logs
  * report kubectl version to the release controller
  * add markdown representation of features
  * add information about featuregate diff in a particular release
  * Skip rhel9 binary not found error for older releases
  * Allow extracted binary name can be set to different
  * Generate RHEL8 based oc and add as target to extract
  * Add RHEL9 oc as linux command in target list
  * Skip release-arch and arch type collision per command
  * OTA-1087: Add update health section to `adm update status`
  * `adm update status`: add fixtures with degraded/unavailable COs
  * Sanitize path using filepath Clean
  * oc adm prune images: fix --certificate-authority flag name in
    validation code
  * pkg/cli/admin/upgrade/rollback: New rollback command
  * pkg/cli/tag: validate tag name on creation
  * Generate oc rhel9 fips compatible binary compiled in rhel9
  * Bump ocp images to 4.16 in addition to go 1.21
  * oc release extract: Introduce --idms-file and deprecate
    icsp-file
  * Skip network.openshift.io/v1alpha1 in describer unit test
  * Bump openshift/api to include to the new CloudCredential
    capability
  * Remove deprecated password defaulting in default config flag
  * Migrate from deprecated ioutils to relevant libraries
  * pkg/cli/admin/release/extract: Log a warning on
  - -credentials-requests without --included
  * Do not force the ancient OS version dist tag, just use whatever
    the OS in question sets.
* Fri Apr 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- add Conflicts for completion subpackages
* Thu Apr 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- fix version output of kubectl binary
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- update to version 4.15.0:
  no changelog available, apparently
* Sat Jan 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- add completions for kubectl that are actually usable
* Mon Jan  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package oc: the openshift command line utility
